
using ETHZ.C0284H.Calculator.CalculatorNode.Visitor;

namespace ETHZ.C0284H.Calculator.CalculatorNode
{ 
	/// <summary>
	/// Operand, represented as double
	/// </summary>	
	public sealed class Operand:INode
	{
        // Value of the operand.
		private readonly double _operandValue;

		/// <summary>
		/// Constructor for an operand
		/// </summary>
		/// <param name="d">
		/// A <see cref="System.Double"/>
		/// </param>
		public Operand (double d)
		{
			_operandValue = d;
		}

		/// <summary>
		/// Return the operand value
		/// </summary>
		/// <returns>
		/// A <see cref="System.Double"/>
		/// </returns>
		public double OperandValue
		{
			get {return _operandValue;}
		}
		
		/// <summary>
		/// Implement double dispatch using this operand and the specific visitor passed as argument
		/// </summary>
		/// <param name="visitor">
		/// A <see cref="IVisitor"/>
		/// </param>
		public void Accept(IVisitor visitor)
		{
		    if (visitor != null)
		    {
		        visitor.VisitOperand(this);
		    }
		}

	    /// <summary>
		/// String representation of an operand
		/// </summary>
		/// <returns>
		/// A <see cref="System.String"/>
		/// </returns>
		public override string ToString ()
		{
			return string.Format("{0}", _operandValue.ToString());
		}        
	}
}
