﻿using System;
using System.Globalization;
using ETHZ.C0284H.Calculator.Instruct.Visitor;

namespace ETHZ.C0284H.Calculator.Instruct
{
    /// <summary>
    /// Instruct for a single operator, in other words - double value.
    /// </summary>
    public sealed class CalculatorInstructOperand : ICalculatorInstruct
    {
        /// <summary>
        /// Operand value. 
        /// </summary>
        private double _value;

        /// <summary>
        ///  Constructor.
        /// </summary>
        /// <param name="value"></param>
        public CalculatorInstructOperand(double value)
        {
            Value = value;
        }

        /// <summary>
        ///  Value property.
        /// </summary>
        public double Value
        {
            get { return _value; }
            private set { _value = value; }
        }

        public string InstructCode
        {
            get
            {
                return Value.ToString(CultureInfo.InvariantCulture);
            }
        }

        /// <summary>
        /// Accepts a visitor.
        /// </summary>
        /// <param name="visitor"></param>
        public void Accept(ICalculatorInstructVisitor visitor)
        {
            if (visitor != null)
            {
                visitor.VisitOperand(this);
            }
        }

        /// <summary>
        /// Operand text.
        /// </summary>
        public String InstructText
        {
            get { return _value.ToString(CultureInfo.InvariantCulture); }
        }
    }
}
